# 🐍 Getting the Essentials (Python + IDE)

To _run_ Python code you first need to install Python on your machine, I recommend if you are on Windows, install this through the Windows store and get the latest version. Find version 3.12 in the Windows Store and download this.

To _write_ Python code you need an Integrated Development Environment (IDE) a fancy title for software (app) where you can write code.  Just like the Notepad app is used to write text. The one I recommend is Visual Studio Code (VSC) by Microsoft, you can download that below.&#x20;

{% hint style="info" %}
Make sure you choose the correct version for the operating system you are running. If you are running Windows you want the Windows version.
{% endhint %}

{% embed url="https://code.visualstudio.com/download" %}
